# pythonc

On installation, this will provide a command : pythonc, which take a path for python module to be compiled.

Usage: #> pythonc /path/of/python/module.py

It includes python3 and an entrypoint for python compiler() method along with some modification to make it easy use like javac.

I have also uploaded an alpine(ubuntu) image along with this package. 
To get the image from docker-hub use follwing command:
#> docker run -it sdbit04/python-with-compiler

